﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using Infragistics.Win;
using System.Drawing;

namespace UltraOptionSetEmbeddedHTML
{
    public class CustomDrawFilter : IUIElementDrawFilter
    {
        public bool DrawElement(DrawPhase drawPhase, ref UIElementDrawParams drawParams)
        {
            // Get specific option set value
            ValueListItem item = (ValueListItem)drawParams.Element.GetContext(typeof(ValueListItem), true);

            using (Font imageFont = new Font(FontFamily.GenericSansSerif, 10, FontStyle.Bold))
            {
                using (SolidBrush brush = new SolidBrush(Color.Black))
                {
                    var originalTextRenderingHint = drawParams.Graphics.TextRenderingHint;
                    try
                    {
                        //// At this point the text should have already been read from the database. In this case I just hard coded it.

                        drawParams.Graphics.TextRenderingHint = System.Drawing.Text.TextRenderingHint.AntiAlias;
                        drawParams.Graphics.DrawString(
                            "Current visit ",
                            imageFont,
                            brush,
                            drawParams.Element.Rect.Location,
                            StringFormat.GenericTypographic);

                        var stringWidth = drawParams.Graphics.MeasureString("Current visit ", imageFont, Int32.MaxValue, StringFormat.GenericTypographic).Width;
                        brush.Color = Color.Blue;

                        drawParams.Graphics.DrawString(
                            " count",
                            imageFont,
                            brush,
                            drawParams.Element.Rect.Location.X + stringWidth, 
                            drawParams.Element.Rect.Location.Y, 
                            StringFormat.GenericTypographic);
                    }
                    finally
                    {
                        drawParams.Graphics.TextRenderingHint = originalTextRenderingHint;
                    }
                }
            }

            return true;
        }

        public DrawPhase GetPhasesToFilter(ref UIElementDrawParams drawParams)
        {
            if (drawParams.Element is TextUIElement && drawParams.Element.Parent is OptionSetOptionButtonUIElement)
            {
                return DrawPhase.BeforeDrawElement;
            }

            return DrawPhase.None;
        }
    }
}
